==> apache-doris-flink-connector-1.6.2-src.tar.gz: apache-doris-flink-connector-1.6.2-src/src/main/java/org/apache/doris/flink/rest/SchemaUtils.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.flink.rest;

import org.apache.doris.flink.rest.models.Field;
import org.apache.doris.flink.rest.models.Schema;
import org.apache.doris.sdk.thrift.TScanColumnDesc;

import java.util.List;

public class SchemaUtils {

    /**
     * convert Doris return schema to inner schema struct.
     *
     * @param tscanColumnDescs Doris BE return schema
     * @return inner schema struct
     */
    public static Schema convertToSchema(List<TScanColumnDesc> tscanColumnDescs) {
        Schema schema = new Schema(tscanColumnDescs.size());
        tscanColumnDescs.stream()
                .forEach(
                        desc ->
                                schema.put(
                                        new Field(
                                                desc.getName(),
                                                desc.getType().name(),
                                                "",
                                                0,
                                                0,
                                                "")));
        return schema;
    }
}

==> apache-doris-flink-connector-25.0.0-src.tar.gz: apache-doris-flink-connector-25.0.0-src/src/main/java/org/apache/doris/flink/rest/SchemaUtils.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.flink.rest;

import org.apache.doris.flink.rest.models.Field;
import org.apache.doris.flink.rest.models.Schema;
import org.apache.doris.sdk.thrift.TScanColumnDesc;

import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

public class SchemaUtils {

    /**
     * convert Doris return schema to inner schema struct.
     *
     * @param tscanColumnDescs Doris BE return schema
     * @return inner schema struct
     */
    public static Schema convertToSchema(List<TScanColumnDesc> tscanColumnDescs) {
        Schema schema = new Schema(tscanColumnDescs.size());
        tscanColumnDescs.stream()
                .forEach(
                        desc ->
                                schema.put(
                                        new Field(
                                                desc.getName(),
                                                desc.getType().name(),
                                                "",
                                                0,
                                                0,
                                                "")));
        return schema;
    }

    public static Schema convertToSchema(
            Schema tableSchema, org.apache.arrow.vector.types.pojo.Schema tscanColumnDescs) {
        Schema schema = new Schema(tscanColumnDescs.getFields().size());
        Map<String, Field> collect =
                tableSchema.getProperties().stream()
                        .collect(Collectors.toMap(Field::getName, Function.identity()));
        tscanColumnDescs
                .getFields()
                .forEach(
                        desc ->
                                schema.put(
                                        new Field(
                                                desc.getName(),
                                                collect.get(desc.getName()).getType(),
                                                "",
                                                0,
                                                0,
                                                "")));
        return schema;
    }
}
